@@ -1,4 +1,5 @@
 import curses
+from .application import StoppingSignal
 
 
 class Interface:
@@ -43,6 +44,8 @@ class Interface:
 
         if self.no_cursor:
             curses.curs_set(0)
+        else:
+            curses.curs_set(1)
 
         while self.application.running():
             self.update(screen)
@@ -52,4 +55,6 @@ class Interface:
             screen.clear()
             curses.curs_set(0)
             self.draw_end(screen)
-            self.application.action(screen)
+
+            while self.application.action(screen):
+                pass
