@@ -6,7 +6,9 @@ import pathlib
 
 
 class Stats:
-    def __init__(self):
+    def __init__(self, runtime_config):
+        self.runtime_config = runtime_config
+
         self.correct_chars = 0
         self.incorrect_chars = 0
 
@@ -16,6 +18,8 @@ class Stats:
         self.buffer = None
         self.finished = False
 
+        self.snaps = []
+
     def set_buffer(self, buffer):
         self.buffer = buffer
 
@@ -29,14 +33,20 @@ class Stats:
     def signal_valid(self):
         self.signal_running()
         self.correct_chars += 1
+        self.take_snap()
 
     def signal_invalid(self):
         self.signal_running()
         self.incorrect_chars += 1
+        self.take_snap()
 
     def signal_stop(self, finished=False):
         self.stop_dtime = datetime.now()
         self.finished = finished
+        self.take_snap()
+
+    def take_snap(self):
+        self.snaps.append(self.produce_record())
 
     @property
     def correct_words(self):
@@ -50,7 +60,7 @@ class Stats:
     def total_seconds(self):
         stop_dtime = self.stop_dtime or datetime.now()
         start_dtime = self.start_dtime or datetime.now()
-        return (stop_dtime - start_dtime).total_seconds() or 1
+        return max(((stop_dtime - start_dtime).total_seconds(), 1))
 
     @property
     def total_minutes(self):
@@ -80,19 +90,30 @@ class Stats:
     def raw_cpm(self):
         return self.total_chars / self.total_minutes
 
+    @property
+    def peak_raw_cpm(self):
+        return max([s["raw_cpm"] for s in self.snaps] + [0.0])
+
+    @property
+    def peak_cpm(self):
+        return max([s["raw_cpm"] for s in self.snaps] + [0.0])
+
+    @property
+    def peak_raw_wpm(self):
+        return self.peak_raw_cpm / 5
+
+    @property
+    def peak_wpm(self):
+        return self.peak_cpm / 5
+
     @property
     def accuracy(self):
         if self.total_chars:
             return self.correct_chars / self.total_chars * 100
         return 100
 
-    def summarize(self, template):
-        print(template.format(stats=self))
-
-    def produce_record(self):
-        return {
-            "start_dtime": self.start_dtime.isoformat(),
-            "stop_dtime": self.stop_dtime.isoformat(),
+    def produce_record(self, for_csv=False):
+        result = {
             "total_seconds": self.total_seconds,
             "total_minutes": self.total_minutes,
             "total_chars": self.total_chars,
@@ -107,6 +128,25 @@ class Stats:
             "raw_cpm": self.raw_cpm,
             "accuracy": self.accuracy,
         }
+        if for_csv:
+            result.update(
+                {
+                    "peak_cpm": self.peak_cpm,
+                    "peak_raw_cpm": self.peak_raw_cpm,
+                    "peak_wpm": self.peak_wpm,
+                    "peak_raw_wpm": self.peak_raw_wpm,
+                    "start_dtime": self.start_dtime.isoformat()
+                    if self.start_dtime
+                    else None,
+                    "stop_dtime": self.stop_dtime.isoformat()
+                    if self.stop_dtime
+                    else None,
+                    "mode": self.runtime_config.mode,
+                    "language": self.runtime_config.language,
+                    "words": self.runtime_config.words,
+                }
+            )
+        return result
 
     def export_to_datafile(self, datafile):
         if datafile is None:
@@ -118,7 +158,7 @@ class Stats:
         pathlib.Path(data_dir).mkdir(exist_ok=True, parents=True)
         exists = os.path.isfile(datafile)
 
-        record = self.produce_record()
+        record = self.produce_record(for_csv=True)
 
         if not exists:
             with open(datafile, "w") as f:
@@ -129,5 +169,3 @@ class Stats:
             with open(datafile, "a") as f:
                 writter = csv.DictWriter(f, fieldnames=record.keys())
                 writter.writerow(record)
-
-        print(f"\nwrote stats to {datafile}")
